import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;

import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;

public class Quiz extends JFrame implements ActionListener {

    Problem      problem;
    String       currentAnswer;

    JLabel       questionLabel;
    JRadioButton answerButtons[];
    JButton      nextButton;

    public Quiz()
    {
        super( "Quiz" );

        loadQuiz();
        initGUI();

        setSize( 600, 200 );
        setLocationRelativeTo( null );
        setDefaultCloseOperation( EXIT_ON_CLOSE );
    }

    private void loadQuiz()
    {
        try
        {
            BufferedReader in = new BufferedReader( new FileReader(
                    "e:/temp/quiz.txt" ) );
            problem = new Problem();
            problem.load( in );
            in.close();
        }
        catch( IOException e )
        {
            System.err.println( "Cannot open quiz.txt" );
            System.exit( 1 );
        }
    }

    private void initGUI()
    {
        Container cp = getContentPane();

        questionLabel = new JLabel();
        cp.add( questionLabel, BorderLayout.NORTH );

        nextButton = new JButton( "Next" );
        nextButton.addActionListener( this );
        cp.add( nextButton, BorderLayout.SOUTH );

        answerButtons = new JRadioButton[4];
        ButtonGroup group = new ButtonGroup();
        JPanel panel = new JPanel();
        panel.setLayout( new GridLayout( answerButtons.length, 1 ) );
        for( int i = 0; i < answerButtons.length; ++i )
        {
            answerButtons[i] = new JRadioButton();
            answerButtons[i].setActionCommand( (char) ('a' + i) + "" );
            answerButtons[i].addActionListener( this );
            group.add( answerButtons[i] );
            panel.add( answerButtons[i] );
        }
        cp.add( panel, BorderLayout.CENTER );

        setProblem();
    }

    private void setProblem()
    {
        questionLabel.setText( problem.question );
        for( int i = 0; i < answerButtons.length; ++i )
            answerButtons[i].setText( problem.answers[i] );
        answerButtons[0].setSelected( true );
        currentAnswer = "a";
    }

    private void setResult()
    {
        int numOfCorrectAnswers = 0;
        if( currentAnswer.equals( problem.correctAnswer ) )
            ++numOfCorrectAnswers;

        questionLabel.setText( "You have answered " + numOfCorrectAnswers
                + " out of 1 question(s) correctly." );
        for( int i = 0; i < answerButtons.length; ++i )
            answerButtons[i].setVisible( false );

        nextButton.setText( "Exit" );
    }

    public void actionPerformed( ActionEvent event )
    {
        String cmd = event.getActionCommand();

        if( cmd.equals( "Next" ) )
            setResult();
        else if( cmd.equals( "Exit" ) )
            System.exit( 0 );
        else
            currentAnswer = cmd;
    }

    public static void main( String args[] )
    {
        (new Quiz()).setVisible( true );
    }

    class Problem {

        String question;
        String answers[];
        String correctAnswer;

        public Problem()
        {
            question = null;
            answers = new String[4];
        }

        public boolean load( BufferedReader in ) throws IOException
        {
            boolean loaded = false;

            if( (question = in.readLine()) != null )
            {
                for( int i = 0; i < answers.length; ++i )
                    answers[i] = in.readLine();
                correctAnswer = in.readLine();
                loaded = true;
            }

            return loaded;
        }

    } // end of class Question

} // end of class Quiz
